# openmeeg

Dummy package for openmeeg.
Please directly install `openmeeg` instead.

```sh
# uninstall current package
$ pip uninstall -y openmeeg
# reinstall the right package
$ pip install openmeeg
```
